﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.ServiceModel;
using WcfService;
using System.ServiceModel.Description;

namespace ServiceStarter
{
    /// <summary>
    /// Our main form
    /// </summary>
    public partial class MainForm : Form
    {
        private ServiceHost _serviceHost;

        /// <summary>
        /// Initializes a new instance of the <see cref="MainForm"/> class.
        /// </summary>
        public MainForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Starts the service
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void button1_Click(object sender, EventArgs e)
        {
            // start service
            if (_serviceHost == null ||                           // first run, no service instantiated
                _serviceHost.State != CommunicationState.Opened)  // second run, but host is closed (again)
            {

                // Create a ServiceHost
                _serviceHost = new ServiceHost(typeof(HelloService));

                // register some events
                _serviceHost.Opened += ShowStatus;
                _serviceHost.Opening += ShowStatus;
                _serviceHost.Faulted += ShowStatus;
                _serviceHost.Closing += ShowStatus;
                _serviceHost.Closed += ShowStatus;


                // Open the ServiceHostBase to create listeners and start listening for messages.
                _serviceHost.Open();

                btnStartStop.Text = "Stop WCF Service";
            }
            else
            {
                _serviceHost.Close();
                btnStartStop.Text = "Start WCF Service";

            }
        }

        /// <summary>
        /// Writes some informations into the txtStatus textbox
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void ShowStatus(object sender, EventArgs e)
        {
            txtStatus.Text = "WCF Service is " + _serviceHost.State.ToString() + "\r\n\r\n";

            if (_serviceHost.State == CommunicationState.Opened) {

                foreach (Uri baseAddress in _serviceHost.BaseAddresses)
                {
                    txtStatus.Text += "Base address: " + baseAddress.ToString() + "\r\n";
                }

                foreach (ServiceEndpoint endpoint in _serviceHost.Description.Endpoints)
                {
                    txtStatus.Text += "\r\n";
                    txtStatus.Text += "Endpoint Address:  " + endpoint.Address.ToString() + "\r\n";
                    txtStatus.Text += "Endpoint Binding:  " + endpoint.Binding.ToString() + "\r\n";
                    txtStatus.Text += "Endpoint Contract: " + endpoint.Contract.ContractType.ToString() + "\r\n";
                }
            }
        }
    }
}
